# -1NeuronPerceptron_Pypi
 1Neuron|Perceptron|_Pypi


 # Reference -
[official python docs](https://packaging.python.org/tutorials/packaging-projects/)

[github docs for github actions](https://docs.github.com/en/actions/guides/building-and-testing-python#publishing-to-package-registries)

[Read me editor](https://readme.so/editor)

## Second
